@@ -26,22 +26,19 @@
 #include <config.h>
 #include "nautilus-desktop-directory-file.h"
 
+#include "nautilus-desktop-metadata.h"
 #include "nautilus-directory-notify.h"
 #include "nautilus-directory-private.h"
 #include "nautilus-file-attributes.h"
 #include "nautilus-file-private.h"
 #include "nautilus-file-utilities.h"
 #include <eel/eel-glib-extensions.h>
-#include <eel/eel-gtk-macros.h>
-#include <gconf/gconf-client.h>
-#include <gconf/gconf-value.h>
 #include "nautilus-desktop-directory.h"
+#include "nautilus-metadata.h"
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <string.h>
 
-#define NAUTILUS_DESKTOP_METADATA_GCONF_PATH "/apps/nautilus/desktop-metadata"
-
 struct NautilusDesktopDirectoryFileDetails {
 	NautilusDesktopDirectory *desktop_directory;
 
@@ -71,14 +68,8 @@ typedef struct {
 	NautilusFileAttributes non_delegated_attributes;
 } DesktopMonitor;
 
-
-static void nautilus_desktop_directory_file_init       (gpointer   object,
-							gpointer   klass);
-static void nautilus_desktop_directory_file_class_init (gpointer   klass);
-
-EEL_CLASS_BOILERPLATE (NautilusDesktopDirectoryFile,
-		       nautilus_desktop_directory_file,
-		       NAUTILUS_TYPE_FILE)
+G_DEFINE_TYPE (NautilusDesktopDirectoryFile, nautilus_desktop_directory_file,
+	       NAUTILUS_TYPE_FILE);
 
 static guint
 desktop_callback_hash (gconstpointer desktop_callback_as_pointer)
@@ -169,7 +160,7 @@ desktop_directory_file_monitor_add (NautilusFile *file,
 	/* Do the rest ourself */
 	nautilus_directory_monitor_add_internal
 		(file->details->directory, file,
-		 client, TRUE, TRUE,
+		 client, TRUE,
 		 monitor->non_delegated_attributes,
 		 NULL, NULL);
 }
@@ -452,140 +443,6 @@ monitor_destroy (gpointer data)
 	g_free (monitor);
 }
 
-static char *
-get_metadata_gconf_path (const char *name,
-			 const char *key)
-{
-	char *res, *escaped_name;
-
-	escaped_name = gconf_escape_key (name, -1);
-	res = g_build_filename (NAUTILUS_DESKTOP_METADATA_GCONF_PATH, escaped_name, key, NULL);
-	g_free (escaped_name);
-
-	return res;
-}
-
-void
-nautilus_desktop_set_metadata_string (NautilusFile *file,
-				      const char *name,
-				      const char *key,
-				      const char *string)
-{
-	GConfClient *client;
-	char *gconf_key;
-
-	client = gconf_client_get_default ();
-	gconf_key = get_metadata_gconf_path (name, key);
-
-	if (string) {
-		gconf_client_set_string (client, gconf_key, string, NULL);
-	} else {
-		gconf_client_unset (client, gconf_key, NULL);
-	}
-
-	g_free (gconf_key);
-	g_object_unref (client);
-
-	if (nautilus_desktop_update_metadata_from_gconf (file, name)) {
-		nautilus_file_changed (file);
-	}
-}
-
-void
-nautilus_desktop_set_metadata_stringv (NautilusFile *file,
-				       const char *name,
-				       const char *key,
-				       char **stringv)
-{
-	GConfClient *client;
-	char *gconf_key;
-	GSList *list;
-	int i;
-
-	client = gconf_client_get_default ();
-	gconf_key = get_metadata_gconf_path (name, key);
-
-	list = NULL;
-	for (i = 0; stringv[i] != NULL; i++) {
-		list = g_slist_prepend (list, stringv[i]);
-	}
-	list = g_slist_reverse (list);
-
-	gconf_client_set_list (client, gconf_key,
-			       GCONF_VALUE_STRING,
-			       list, NULL);
-
-	g_slist_free (list);
-	g_free (gconf_key);
-	g_object_unref (client);
-
-	if (nautilus_desktop_update_metadata_from_gconf (file, name)) {
-		nautilus_file_changed (file);
-	}
-}
-
-gboolean
-nautilus_desktop_update_metadata_from_gconf (NautilusFile *file,
-					     const char *name)
-{
-	GConfClient *client;
-	GSList *entries, *l;
-	char *dir;
-	const char *key;
-	GConfEntry *entry;
-	GConfValue *value;
-	GFileInfo *info;
-	gboolean changed;
-	char *gio_key;
-	GSList *value_list;
-	char **strv;
-	int i;
-
-	client = gconf_client_get_default ();
-
-	dir = get_metadata_gconf_path (name, NULL);
-	entries = gconf_client_all_entries (client, dir, NULL);
-	g_free (dir);
-
-	info = g_file_info_new ();
-
-	for (l = entries; l != NULL; l = l->next) {
-		entry = l->data;
-
-		key = gconf_entry_get_key (entry);
-		value = gconf_entry_get_value (entry);
-
-		key = strrchr (key, '/') + 1;
-
-		gio_key = g_strconcat ("metadata::", key, NULL);
-		if (value->type == GCONF_VALUE_STRING) {
-			g_file_info_set_attribute_string (info, gio_key,
-							  gconf_value_get_string (value));
-		} else if (value->type == GCONF_VALUE_LIST &&
-			   gconf_value_get_list_type (value) == GCONF_VALUE_STRING) {
-			value_list = gconf_value_get_list (value);
-			strv = g_new (char *, g_slist_length (value_list) + 1);
-			for (i = 0; value_list != NULL; i++, value_list = value_list->next) {
-				strv[i] = l->data;
-			}
-			strv[i] = NULL;
-			g_file_info_set_attribute_stringv (info, gio_key, strv);
-			g_free (strv);
-		}
-
-		g_free (gio_key);
-
-		gconf_entry_unref (entry);
-	}
-
-	changed = nautilus_file_update_metadata_from_info (file, info);
-
-	g_object_unref (info);
-	g_object_unref (client);
-
-	return changed;
-}
-
 static void
 nautilus_desktop_directory_file_set_metadata (NautilusFile           *file,
 					      const char             *key,
@@ -599,22 +456,21 @@ nautilus_desktop_directory_file_set_metadata_as_list (NautilusFile           *fi
 						      const char             *key,
 						      char                  **value)
 {
-	nautilus_desktop_set_metadata_stringv (file, "directory", key, value);
+	nautilus_desktop_set_metadata_stringv (file, "directory", key, (const gchar **) value);
 }
 
 static void
-nautilus_desktop_directory_file_init (gpointer object, gpointer klass)
+nautilus_desktop_directory_file_init (NautilusDesktopDirectoryFile *desktop_file)
 {
-	NautilusDesktopDirectoryFile *desktop_file;
 	NautilusDesktopDirectory *desktop_directory;
 	NautilusDirectory *real_dir;
 	NautilusFile *real_dir_file;
 
-	desktop_file = NAUTILUS_DESKTOP_DIRECTORY_FILE (object);
+	desktop_file->details = G_TYPE_INSTANCE_GET_PRIVATE (desktop_file,
+							     NAUTILUS_TYPE_DESKTOP_DIRECTORY_FILE,
+							     NautilusDesktopDirectoryFileDetails);
 
 	desktop_directory = NAUTILUS_DESKTOP_DIRECTORY (nautilus_directory_get_by_uri (EEL_DESKTOP_URI));
-
-	desktop_file->details = g_new0 (NautilusDesktopDirectoryFileDetails, 1);
 	desktop_file->details->desktop_directory = desktop_directory;
 
 	desktop_file->details->callbacks = g_hash_table_new
@@ -628,7 +484,7 @@ nautilus_desktop_directory_file_init (gpointer object, gpointer klass)
 	
 	desktop_file->details->real_dir_file = real_dir_file;
 
-	nautilus_desktop_update_metadata_from_gconf (NAUTILUS_FILE (desktop_file), "directory");
+	nautilus_desktop_update_metadata_from_keyfile (NAUTILUS_FILE (desktop_file), "directory");
 
 	g_signal_connect_object (real_dir_file, "changed",
 				 G_CALLBACK (real_file_changed_callback), desktop_file, 0);
@@ -668,16 +524,13 @@ desktop_finalize (GObject *object)
 	g_hash_table_destroy (desktop_file->details->monitors);
 
 	nautilus_file_unref (desktop_file->details->real_dir_file);
-
-	g_free (desktop_file->details);
-
 	nautilus_directory_unref (NAUTILUS_DIRECTORY (desktop_directory));
 
-	EEL_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
+	G_OBJECT_CLASS (nautilus_desktop_directory_file_parent_class)->finalize (object);
 }
 
 static void
-nautilus_desktop_directory_file_class_init (gpointer klass)
+nautilus_desktop_directory_file_class_init (NautilusDesktopDirectoryFileClass *klass)
 {
 	GObjectClass *object_class;
 	NautilusFileClass *file_class;
@@ -700,4 +553,6 @@ nautilus_desktop_directory_file_class_init (gpointer klass)
 	file_class->get_where_string = desktop_directory_file_get_where_string;
 	file_class->set_metadata = nautilus_desktop_directory_file_set_metadata;
 	file_class->set_metadata_as_list = nautilus_desktop_directory_file_set_metadata_as_list;
+
+	g_type_class_add_private (klass, sizeof (NautilusDesktopDirectoryFileDetails));
 }
