@@ -139,6 +139,11 @@ append_label (GtkWidget *vbox,
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 0);
 	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
 
+	/* setting can_focus to FALSE will allow to make the label
+	 * selectable but without the cursor showing.
+	 */
+	gtk_widget_set_can_focus (label, FALSE);
+
 	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 	gtk_widget_show (label);
 
@@ -179,20 +184,15 @@ static void
 exif_content_callback (ExifContent *content, gpointer data)
 {
 	struct ExifAttribute *attribute;
-#ifndef HAVE_OLD_EXIF
 	char b[1024];
-#endif
 
 	attribute = (struct ExifAttribute *)data;
 	if (attribute->found) {
 		return;
 	}
 
-#ifdef HAVE_OLD_EXIF
-        attribute->value = g_strdup (exif_content_get_value (content, attribute->tag));
-#else
         attribute->value = g_strdup (exif_content_get_value (content, attribute->tag, b, sizeof(b)));
-#endif
+
 	if (attribute->value != NULL) {
 		attribute->found = TRUE;
 	}
@@ -295,11 +295,7 @@ append_xmp_value_pair (NautilusImagePropertiesPage *page,
 	XmpStringPtr value;
 
 	value = xmp_string_new();
-#ifdef HAVE_EXEMPI_NEW_API
 	if (xmp_get_property (xmp, ns, propname, value, &options)) {
-#else
-	if (xmp_get_property_and_bits (xmp, ns, propname, value, &options)) {
-#endif
 		if (XMP_IS_PROP_SIMPLE (options)) {
 			append_label_take_str
 				(page->details->vbox,
@@ -362,6 +358,10 @@ load_finished (NautilusImagePropertiesPage *page)
 
 	gtk_widget_destroy (page->details->loading_label);
 
+	if (page->details->loader != NULL) {
+		gdk_pixbuf_loader_close (page->details->loader, NULL);
+	}
+
 	if (page->details->got_size) {
 #ifdef HAVE_EXIF
                 ExifData *exif_data;
@@ -404,7 +404,6 @@ load_finished (NautilusImagePropertiesPage *page)
 	}
 
 	if (page->details->loader != NULL) {
-		gdk_pixbuf_loader_close (page->details->loader, NULL);
 		g_object_unref (page->details->loader);
 		page->details->loader = NULL;
 	}
