@@ -578,6 +578,8 @@ nautilus_window_constructed (GObject *self)
 	gtk_widget_show (table);
 	gtk_container_add (GTK_CONTAINER (window), table);
 
+	gtk_widget_set_margin_bottom (GTK_WIDGET (window), 3);
+
 	statusbar = gtk_statusbar_new ();
 	gtk_widget_set_name (statusbar, "statusbar-noborder");
 	window->details->statusbar = statusbar;
@@ -746,6 +748,9 @@ nautilus_window_finalize (GObject *object)
 		g_object_unref (window->details->bookmark_list);
 	}
 
+	g_signal_handlers_disconnect_by_func (nautilus_window_state,
+					      side_pane_id_changed, window);
+
 	/* nautilus_window_close() should have run */
 	g_assert (window->details->panes == NULL);
 
